/*  VER 036  TAB P   $Id: newsconfig.h,v 1.4.2.1 2003/01/22 10:18:25 egil Exp $
 *
 *  news configuration
 *
 *  copyright 1999 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: newsconfig.h,v $
 *  Revision 1.4.2.1  2003/01/22 10:18:25  egil
 *  Implemented hostconfig, removed storageapi
 *
 *  Revision 1.4  1999/04/19 03:32:39  src
 *  Standard profile in $PATHETC/newsx.conf
 *
 *  Revision 1.3  1999/04/08 10:48:54  src
 *  Extendeddbz to configure
 *
 *  Revision 1.2  1999/04/08 10:19:37  src
 *  Check for extendeddbz in configure
 *
 *  Revision 1.1  1999/03/07 14:58:18  src
 *  Read newsconfig supported. Storage API supported.
 *
 */

#ifdef INIT_CONFIG
#define INIT(v) = v
#else
#define INIT(v)
#endif

char *cfg_newshome  INIT(NEWSHOME);     /* -H newshome */
char *cfg_etc       INIT(PATHETC);
char *cfg_newsbin   INIT(NEWSBIN);
char *cfg_spool     INIT(SPOOL);
char *cfg_history   INIT(HISTORY);      /* -h history */
char *cfg_active    INIT(ACTIVE);       /* -A active */
char *cfg_batch     INIT(BATCH);        /* -B batch */
char *cfg_incoming  INIT(INCOMING);     /* -I incoming */
char *cfg_inhosts   INIT(INHOSTS);      /* -K in.hosts */
char *cfg_newsfeeds INIT(NEWSFEEDS);    /* -N newsfeeds */
char *cfg_locks     INIT(LOCKS);        /* -P locks */
char *cfg_hostconfig INIT(HOSTCONFIG);

int cfg_extendeddbz INIT(INN_EXTENDEDDBZ);


